==> core-1.23.0-sources.jar: software/amazon/awscdk/core/ICfnResourceOptions.java <==
package software.amazon.awscdk.core;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:47.235Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ICfnResourceOptions")
@software.amazon.jsii.Jsii.Proxy(ICfnResourceOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ICfnResourceOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * A condition to associate with this resource.
     * <p>
     * This means that only if the condition evaluates to 'true' when the stack
     * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
     * there is no need to use it in CDK projects.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnCondition getCondition() {
        return null;
    }

    /**
     * A condition to associate with this resource.
     * <p>
     * This means that only if the condition evaluates to 'true' when the stack
     * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
     * there is no need to use it in CDK projects.
     */
    @software.amazon.jsii.Optional
    default void setCondition(final software.amazon.awscdk.core.CfnCondition value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setCondition(software.amazon.awscdk.core.CfnCondition)' is not implemented!");
    }

    /**
     * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
     * <p>
     * To signal a
     * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
     * to the stack events so that you track the number of signals sent.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnCreationPolicy getCreationPolicy() {
        return null;
    }

    /**
     * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
     * <p>
     * To signal a
     * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
     * to the stack events so that you track the number of signals sent.
     */
    @software.amazon.jsii.Optional
    default void setCreationPolicy(final software.amazon.awscdk.core.CfnCreationPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setCreationPolicy(software.amazon.awscdk.core.CfnCreationPolicy)' is not implemented!");
    }

    /**
     * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
     * <p>
     * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
     * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
     * that lead to resources being removed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnDeletionPolicy getDeletionPolicy() {
        return null;
    }

    /**
     * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
     * <p>
     * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
     * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
     * that lead to resources being removed.
     */
    @software.amazon.jsii.Optional
    default void setDeletionPolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setDeletionPolicy(software.amazon.awscdk.core.CfnDeletionPolicy)' is not implemented!");
    }

    /**
     * Metadata associated with the CloudFormation resource.
     * <p>
     * This is not the same as the construct metadata which can be added
     * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * Metadata associated with the CloudFormation resource.
     * <p>
     * This is not the same as the construct metadata which can be added
     * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
     */
    @software.amazon.jsii.Optional
    default void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setMetadata(java.util.Map<java.lang.String, java.lang.Object>)' is not implemented!");
    }

    /**
     * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
     * <p>
     * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
     * scheduled action is associated with the Auto Scaling group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnUpdatePolicy getUpdatePolicy() {
        return null;
    }

    /**
     * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
     * <p>
     * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
     * scheduled action is associated with the Auto Scaling group.
     */
    @software.amazon.jsii.Optional
    default void setUpdatePolicy(final software.amazon.awscdk.core.CfnUpdatePolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setUpdatePolicy(software.amazon.awscdk.core.CfnUpdatePolicy)' is not implemented!");
    }

    /**
     * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnDeletionPolicy getUpdateReplacePolicy() {
        return null;
    }

    /**
     * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
     */
    @software.amazon.jsii.Optional
    default void setUpdateReplacePolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setUpdateReplacePolicy(software.amazon.awscdk.core.CfnDeletionPolicy)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.ICfnResourceOptions {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * A condition to associate with this resource.
         * <p>
         * This means that only if the condition evaluates to 'true' when the stack
         * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
         * there is no need to use it in CDK projects.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.CfnCondition getCondition() {
            return this.jsiiGet("condition", software.amazon.awscdk.core.CfnCondition.class);
        }

        /**
         * A condition to associate with this resource.
         * <p>
         * This means that only if the condition evaluates to 'true' when the stack
         * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
         * there is no need to use it in CDK projects.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setCondition(final software.amazon.awscdk.core.CfnCondition value) {
            this.jsiiSet("condition", value);
        }

        /**
         * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
         * <p>
         * To signal a
         * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
         * to the stack events so that you track the number of signals sent.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.CfnCreationPolicy getCreationPolicy() {
            return this.jsiiGet("creationPolicy", software.amazon.awscdk.core.CfnCreationPolicy.class);
        }

        /**
         * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
         * <p>
         * To signal a
         * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
         * to the stack events so that you track the number of signals sent.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setCreationPolicy(final software.amazon.awscdk.core.CfnCreationPolicy value) {
            this.jsiiSet("creationPolicy", value);
        }

        /**
         * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
         * <p>
         * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
         * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
         * that lead to resources being removed.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.CfnDeletionPolicy getDeletionPolicy() {
            return this.jsiiGet("deletionPolicy", software.amazon.awscdk.core.CfnDeletionPolicy.class);
        }

        /**
         * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
         * <p>
         * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
         * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
         * that lead to resources being removed.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setDeletionPolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
            this.jsiiSet("deletionPolicy", value);
        }

        /**
         * Metadata associated with the CloudFormation resource.
         * <p>
         * This is not the same as the construct metadata which can be added
         * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return java.util.Optional.ofNullable((java.util.Map<java.lang.String, java.lang.Object>)(this.jsiiGet("metadata", java.util.Map.class))).map(java.util.Collections::unmodifiableMap).orElse(null);
        }

        /**
         * Metadata associated with the CloudFormation resource.
         * <p>
         * This is not the same as the construct metadata which can be added
         * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this.jsiiSet("metadata", value);
        }

        /**
         * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
         * <p>
         * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
         * scheduled action is associated with the Auto Scaling group.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.CfnUpdatePolicy getUpdatePolicy() {
            return this.jsiiGet("updatePolicy", software.amazon.awscdk.core.CfnUpdatePolicy.class);
        }

        /**
         * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
         * <p>
         * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
         * scheduled action is associated with the Auto Scaling group.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setUpdatePolicy(final software.amazon.awscdk.core.CfnUpdatePolicy value) {
            this.jsiiSet("updatePolicy", value);
        }

        /**
         * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.CfnDeletionPolicy getUpdateReplacePolicy() {
            return this.jsiiGet("updateReplacePolicy", software.amazon.awscdk.core.CfnDeletionPolicy.class);
        }

        /**
         * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setUpdateReplacePolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
            this.jsiiSet("updateReplacePolicy", value);
        }
    }
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/ICfnResourceOptions.java <==
package software.amazon.awscdk.core;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:48.646Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ICfnResourceOptions")
@software.amazon.jsii.Jsii.Proxy(ICfnResourceOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ICfnResourceOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * A condition to associate with this resource.
     * <p>
     * This means that only if the condition evaluates to 'true' when the stack
     * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
     * there is no need to use it in CDK projects.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnCondition getCondition() {
        return null;
    }

    /**
     * A condition to associate with this resource.
     * <p>
     * This means that only if the condition evaluates to 'true' when the stack
     * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
     * there is no need to use it in CDK projects.
     */
    @software.amazon.jsii.Optional
    default void setCondition(final software.amazon.awscdk.core.CfnCondition value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setCondition(software.amazon.awscdk.core.CfnCondition)' is not implemented!");
    }

    /**
     * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
     * <p>
     * To signal a
     * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
     * to the stack events so that you track the number of signals sent.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnCreationPolicy getCreationPolicy() {
        return null;
    }

    /**
     * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
     * <p>
     * To signal a
     * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
     * to the stack events so that you track the number of signals sent.
     */
    @software.amazon.jsii.Optional
    default void setCreationPolicy(final software.amazon.awscdk.core.CfnCreationPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setCreationPolicy(software.amazon.awscdk.core.CfnCreationPolicy)' is not implemented!");
    }

    /**
     * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
     * <p>
     * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
     * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
     * that lead to resources being removed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnDeletionPolicy getDeletionPolicy() {
        return null;
    }

    /**
     * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
     * <p>
     * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
     * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
     * that lead to resources being removed.
     */
    @software.amazon.jsii.Optional
    default void setDeletionPolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setDeletionPolicy(software.amazon.awscdk.core.CfnDeletionPolicy)' is not implemented!");
    }

    /**
     * Metadata associated with the CloudFormation resource.
     * <p>
     * This is not the same as the construct metadata which can be added
     * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * Metadata associated with the CloudFormation resource.
     * <p>
     * This is not the same as the construct metadata which can be added
     * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
     */
    @software.amazon.jsii.Optional
    default void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setMetadata(java.util.Map<java.lang.String, java.lang.Object>)' is not implemented!");
    }

    /**
     * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
     * <p>
     * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
     * scheduled action is associated with the Auto Scaling group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnUpdatePolicy getUpdatePolicy() {
        return null;
    }

    /**
     * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
     * <p>
     * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
     * scheduled action is associated with the Auto Scaling group.
     */
    @software.amazon.jsii.Optional
    default void setUpdatePolicy(final software.amazon.awscdk.core.CfnUpdatePolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setUpdatePolicy(software.amazon.awscdk.core.CfnUpdatePolicy)' is not implemented!");
    }

    /**
     * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.CfnDeletionPolicy getUpdateReplacePolicy() {
        return null;
    }

    /**
     * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
     */
    @software.amazon.jsii.Optional
    default void setUpdateReplacePolicy(final software.amazon.awscdk.core.CfnDeletionPolicy value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setUpdateReplacePolicy(software.amazon.awscdk.core.CfnDeletionPolicy)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.ICfnResourceOptions {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * A condition to associate with this resource.
         * <p>
         * This means that only if the condition evaluates to 'true' when the stack
         * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
         * there is no need to use it in CDK projects.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCondition getCondition() {
            return this.jsiiGet("condition", software.amazon.awscdk.core.CfnCondition.class);
        }

        /**
         * A condition to associate with this resource.
         * <p>
         * This means that only if the condition evaluates to 'true' when the stack
         * is deployed, the resource will be included. This is provided to allow CDK projects to produce legacy templates, but noramlly
         * there is no need to use it in CDK projects.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setCondition(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCondition value) {
            this.jsiiSet("condition", value);
        }

        /**
         * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
         * <p>
         * To signal a
         * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
         * to the stack events so that you track the number of signals sent.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCreationPolicy getCreationPolicy() {
            return this.jsiiGet("creationPolicy", software.amazon.awscdk.core.CfnCreationPolicy.class);
        }

        /**
         * Associate the CreationPolicy attribute with a resource to prevent its status from reaching create complete until AWS CloudFormation receives a specified number of success signals or the timeout period is exceeded.
         * <p>
         * To signal a
         * resource, you can use the cfn-signal helper script or SignalResource API. AWS CloudFormation publishes valid signals
         * to the stack events so that you track the number of signals sent.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setCreationPolicy(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCreationPolicy value) {
            this.jsiiSet("creationPolicy", value);
        }

        /**
         * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
         * <p>
         * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
         * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
         * that lead to resources being removed.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnDeletionPolicy getDeletionPolicy() {
            return this.jsiiGet("deletionPolicy", software.amazon.awscdk.core.CfnDeletionPolicy.class);
        }

        /**
         * With the DeletionPolicy attribute you can preserve or (in some cases) backup a resource when its stack is deleted.
         * <p>
         * You specify a DeletionPolicy attribute for each resource that you want to control. If a resource has no DeletionPolicy
         * attribute, AWS CloudFormation deletes the resource by default. Note that this capability also applies to update operations
         * that lead to resources being removed.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setDeletionPolicy(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnDeletionPolicy value) {
            this.jsiiSet("deletionPolicy", value);
        }

        /**
         * Metadata associated with the CloudFormation resource.
         * <p>
         * This is not the same as the construct metadata which can be added
         * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return java.util.Optional.ofNullable((java.util.Map<java.lang.String, java.lang.Object>)(this.jsiiGet("metadata", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))))).map(java.util.Collections::unmodifiableMap).orElse(null);
        }

        /**
         * Metadata associated with the CloudFormation resource.
         * <p>
         * This is not the same as the construct metadata which can be added
         * using construct.addMetadata(), but would not appear in the CloudFormation template automatically.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setMetadata(final @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> value) {
            this.jsiiSet("metadata", value);
        }

        /**
         * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
         * <p>
         * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
         * scheduled action is associated with the Auto Scaling group.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnUpdatePolicy getUpdatePolicy() {
            return this.jsiiGet("updatePolicy", software.amazon.awscdk.core.CfnUpdatePolicy.class);
        }

        /**
         * Use the UpdatePolicy attribute to specify how AWS CloudFormation handles updates to the AWS::AutoScaling::AutoScalingGroup resource.
         * <p>
         * AWS CloudFormation invokes one of three update policies depending on the type of change you make or whether a
         * scheduled action is associated with the Auto Scaling group.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setUpdatePolicy(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnUpdatePolicy value) {
            this.jsiiSet("updatePolicy", value);
        }

        /**
         * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnDeletionPolicy getUpdateReplacePolicy() {
            return this.jsiiGet("updateReplacePolicy", software.amazon.awscdk.core.CfnDeletionPolicy.class);
        }

        /**
         * Use the UpdateReplacePolicy attribute to retain or (in some cases) backup the existing physical instance of a resource when it is replaced during a stack update operation.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setUpdateReplacePolicy(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnDeletionPolicy value) {
            this.jsiiSet("updateReplacePolicy", value);
        }
    }
}
